@@ -97,11 +97,20 @@ class TestFs(pyfuse3.Operations):
                 token, self.hello_name, await self.getattr(self.hello_inode), 1)
         return
 
+    async def setxattr(self, inode, name, value, ctx):
+        if inode != pyfuse3.ROOT_INODE or name != b'command':
+            raise pyfuse3.FUSEError(errno.ENOTSUP)
+
+        if value == b'terminate':
+            pyfuse3.terminate()
+        else:
+            raise pyfuse3.FUSEError(errno.EINVAL)
+
     async def open(self, inode, flags, ctx):
         if inode != self.hello_inode:
             raise pyfuse3.FUSEError(errno.ENOENT)
         if flags & os.O_RDWR or flags & os.O_WRONLY:
-            raise pyfuse3.FUSEError(errno.EPERM)
+            raise pyfuse3.FUSEError(errno.EACCES)
         return pyfuse3.FileInfo(fh=inode)
 
     async def read(self, fh, off, size):
