@@ -308,9 +308,11 @@ class Operations:
         :manpage:`open(2)` manpage and defined in the `os` module (with the
         exception of ``O_CREAT``, ``O_EXCL``, ``O_NOCTTY`` and ``O_TRUNC``)
 
-        This method must return an integer file handle. The file handle will be
-        passed to the `read`, `write`, `flush`, `fsync` and `release` methods to
-        identify the open file.
+        This method must return a `FileInfo` instance. The `FileInfo.fh` field
+        must contain an integer file handle, which will be passed to the `read`,
+        `write`, `flush`, `fsync` and `release` methods to identify the open
+        file. The `FileInfo` instance may also have relevant configuration
+        attributes set; see the `FileInfo` documentation for more information.
         '''
 
         raise FUSEError(errno.ENOSYS)
@@ -549,9 +551,9 @@ class Operations:
 
         *ctx* will be a `RequestContext` instance.
 
-        The method must return a tuple of the form *(fh, attr)*, where *fh* is a
-        file handle like the one returned by `open` and *attr* is an
-        `EntryAttributes` instance with the attributes of the newly created
+        The method must return a tuple of the form *(fi, attr)*, where *fi* is a
+        FileInfo instance handle like the one returned by `open` and *attr* is
+        an `EntryAttributes` instance with the attributes of the newly created
         directory entry.
 
         (Successful) execution of this handler increases the lookup count for
