@@ -29,9 +29,7 @@ from util import fuse_test_marker, wait_for_mount, umount, cleanup
 
 pytestmark = fuse_test_marker()
 
-@pytest.yield_fixture()
-def testfs(tmpdir):
-
+def get_mp():
     # We can't use forkserver because we have to make sure
     # that the server inherits the per-test stdout/stderr file
     # descriptors.
@@ -43,7 +41,13 @@ def testfs(tmpdir):
     if threading.active_count() != 1:
         raise RuntimeError("Multi-threaded test running is not supported")
 
+    return mp
+
+
+@pytest.yield_fixture()
+def testfs(tmpdir):
     mnt_dir = str(tmpdir)
+    mp = get_mp()
     with mp.Manager() as mgr:
         cross_process = mgr.Namespace()
         mount_process = mp.Process(target=run_fs,
@@ -54,7 +58,7 @@ def testfs(tmpdir):
             wait_for_mount(mount_process, mnt_dir)
             yield (mnt_dir, cross_process)
         except:
-            cleanup(mnt_dir)
+            cleanup(mnt_process, mnt_dir)
             raise
         else:
             umount(mount_process, mnt_dir)
@@ -129,6 +133,25 @@ def test_attr_timeout(testfs):
         os.fstat(fh.fileno())
         assert fs_state.getattr_called
 
+def test_terminate(tmpdir):
+    mnt_dir = str(tmpdir)
+    mp = get_mp()
+    with mp.Manager() as mgr:
+        fs_state = mgr.Namespace()
+        mount_process = mp.Process(target=run_fs,
+                                   args=(mnt_dir, fs_state))
+
+        mount_process.start()
+        try:
+            wait_for_mount(mount_process, mnt_dir)
+            pyfuse3.setxattr(mnt_dir, 'command', b'terminate')
+            mount_process.join(5)
+            assert mount_process.exitcode is not None
+        except:
+            cleanup(mount_process, mnt_dir)
+            raise
+
+
 class Fs(pyfuse3.Operations):
     def __init__(self, cross_process):
         super(Fs, self).__init__()
@@ -198,7 +221,7 @@ class Fs(pyfuse3.Operations):
         if inode != self.hello_inode:
             raise pyfuse3.FUSEError(errno.ENOENT)
         if flags & os.O_RDWR or flags & os.O_WRONLY:
-            raise pyfuse3.FUSEError(errno.EPERM)
+            raise pyfuse3.FUSEError(errno.EACCES)
         return pyfuse3.FileInfo(fh=inode)
 
     async def read(self, fh, off, size):
@@ -212,16 +235,22 @@ class Fs(pyfuse3.Operations):
 
         if value == b'forget_entry':
             pyfuse3.invalidate_entry_async(pyfuse3.ROOT_INODE, self.hello_name)
+
+            # Make sure that the request is pending before we return
+            await trio.sleep(0.1)
+
         elif value == b'forget_inode':
             pyfuse3.invalidate_inode(self.hello_inode)
+
         elif value == b'store':
             pyfuse3.notify_store(self.hello_inode, offset=0,
                                  data=self.hello_data)
+
+        elif value == b'terminate':
+            pyfuse3.terminate()
         else:
             raise FUSEError(errno.EINVAL)
 
-        # Make sure that the request is pending before we return
-        await trio.sleep(0.1)
 
 def run_fs(mountpoint, cross_process):
     # Logging (note that we run in a new process, so we can't
